@@ -1,10 +1,10 @@
-# $Id: SQLite.pm 70 2019-01-04 19:39:59Z stro $
+# $Id: SQLite.pm 73 2019-01-23 22:29:38Z stro $
 
 package CPAN::SQLite;
 use strict;
 use warnings;
 
-our $VERSION = '0.214';
+our $VERSION = '0.215';
 
 use English qw/-no_match_vars/;
 
@@ -20,50 +20,56 @@ our $db_name = 'cpandb.sql';
 use constant WIN32 => $^O eq 'MSWin32';
 
 sub new {
-    my $class = shift;
-    my %args = @_;
+  my $class = shift;
+  my %args  = @_;
 
-    my ($CPAN, $update_indices);
-    my $db_dir = $args{db_dir};
-    my $urllist = [];
-    my $keep_source_where;
-    # for testing under Darwin, must load CPAN::MyConfig contained
-    # in PERL5LIB, as File::HomeDir doesn't use this
-    if ($ENV{CPAN_SQLITE_TESTING}) {
-      eval {require CPAN::MyConfig;};
+  my ($CPAN, $update_indices);
+  my $db_dir  = $args{db_dir};
+  my $urllist = [];
+  my $keep_source_where;
+
+  # for testing under Darwin, must load CPAN::MyConfig contained
+  # in PERL5LIB, as File::HomeDir doesn't use this
+  if ($ENV{CPAN_SQLITE_TESTING}) {
+    eval { require CPAN::MyConfig; };
+  }
+  eval { require CPAN; CPAN::HandleConfig->load; };
+  if (not $@ and not defined $args{CPAN}) {
+    $CPAN              = $CPAN::Config->{cpan_home};
+    $db_dir            = $CPAN;
+    $keep_source_where = $CPAN::Config->{keep_source_where};
+    $urllist           = $CPAN::Config->{urllist};
+
+    # Sometimes this directory doesn't exist (like on new installations)
+    unless (-d $CPAN) {
+      eval { File::Path::mkpath($CPAN); };    # copied from CPAN.pm
     }
-    eval {require CPAN; CPAN::HandleConfig->load;};
-    if ( not $@ and not defined $args{CPAN} ) {
-      $CPAN = $CPAN::Config->{cpan_home};
-      $db_dir = $CPAN;
-      $keep_source_where = $CPAN::Config->{keep_source_where};
-      $urllist = $CPAN::Config->{urllist};
-      # Sometimes this directory doesn't exist (like on new installations)
-      unless (-d $CPAN) {
-          eval { File::Path::mkpath($CPAN); }; # copied from CPAN.pm
-      }
-      die qq{The '$CPAN' directory doesn't exist} unless -d $CPAN;
-      $update_indices = 0;
-    }
-    else {
-      $CPAN = $args{CPAN} || '';
-      die qq{Please specify the CPAN location} unless defined $CPAN;
-      die qq{The '$CPAN' directory doesn't exist} unless (-d $CPAN);
-      $update_indices = (-f File::Spec->catfile($CPAN, 'MIRRORING.FROM')) ?
-        0 : 1;
-    }
-    push @$urllist, q{http://www.cpan.org/};
-    $db_dir ||= cwd;
-    my $self = {%args, CPAN => $CPAN, update_indices => $update_indices,
-                db_name => $db_name, urllist => $urllist,
-                keep_source_where => $keep_source_where, db_dir => $db_dir};
-    return bless $self, $class;
+    die qq{The '$CPAN' directory doesn't exist} unless -d $CPAN;
+    $update_indices = 0;
+  } else {
+    $CPAN = $args{CPAN} || '';
+    die qq{Please specify the CPAN location} unless defined $CPAN;
+    die qq{The '$CPAN' directory doesn't exist} unless (-d $CPAN);
+    $update_indices = (-f File::Spec->catfile($CPAN, 'MIRRORING.FROM')) ? 0 : 1;
+  }
+  push @$urllist, q{http://www.cpan.org/};
+  $db_dir ||= cwd;
+  my $self = {
+    %args,
+    CPAN              => $CPAN,
+    update_indices    => $update_indices,
+    db_name           => $db_name,
+    urllist           => $urllist,
+    keep_source_where => $keep_source_where,
+    db_dir            => $db_dir
+  };
+  return bless $self, $class;
 }
 
 sub index {
   my ($self, %args) = @_;
   require CPAN::SQLite::Index;
-  my %wanted = map {$_ => $self->{$_}} qw(CPAN ignore update_indices db_name db_dir keep_source_where setup reindex urllist);
+  my %wanted = map { $_ => $self->{$_} } qw(CPAN ignore update_indices db_name db_dir keep_source_where setup reindex urllist);
   my $log_dir = $self->{CPAN} || $self->{db_dir};
   die qq{Please create the directory '$log_dir' first} unless -d $log_dir;
   my $index = CPAN::SQLite::Index->new(%wanted, %args, log_dir => $log_dir);
@@ -77,9 +83,9 @@ sub index {
 sub query {
   my ($self, %args) = @_;
   require CPAN::SQLite::Search;
-  my %wanted = map {$_ => $self->{$_}} qw(max_results CPAN db_name db_dir meta_obj);
+  my %wanted = map { $_ => $self->{$_} } qw(max_results CPAN db_name db_dir meta_obj);
   my $query = CPAN::SQLite::Search->new(%wanted, %args);
-  %wanted = map {$_ => $self->{$_}} qw(mode query id name);
+  %wanted = map { $_ => $self->{$_} } qw(mode query id name);
   $query->query(%wanted, %args) or do {
     warn qq{Query failed!};
     return;
@@ -98,7 +104,7 @@ CPAN::SQLite - maintain and search a minimal CPAN database
 
 =head1 VERSION
 
-version 0.214
+version 0.215
 
 =head1 SYNOPSIS
 
