@@ -1,13 +1,13 @@
-# $Id: Index.pm 70 2019-01-04 19:39:59Z stro $
+# $Id: Index.pm 73 2019-01-23 22:29:38Z stro $
 
 package CPAN::SQLite::DBI::Index;
 use strict;
 use warnings;
 
 BEGIN {
-  our $VERSION = '0.214';
-  $CPAN::SQLite::DBI::Index::info::VERSION = $VERSION;
-  $CPAN::SQLite::DBI::Index::mods::VERSION = $VERSION;
+  our $VERSION = '0.215';
+  $CPAN::SQLite::DBI::Index::info::VERSION  = $VERSION;
+  $CPAN::SQLite::DBI::Index::mods::VERSION  = $VERSION;
   $CPAN::SQLite::DBI::Index::dists::VERSION = $VERSION;
   $CPAN::SQLite::DBI::Index::auths::VERSION = $VERSION;
 }
@@ -29,10 +29,8 @@ use CPAN::SQLite::DBI qw($dbh);
 
 sub fetch_ids {
   my $self = shift;
-  my $sql = sprintf(qq{SELECT %s,%s,%s FROM %s},
-                    $self->{id}, $self->{name}, 'dist_vers',
-                    $self->{table});
-  my $sth = $dbh->prepare($sql) or do {
+  my $sql  = sprintf(qq{SELECT %s,%s,%s FROM %s}, $self->{id}, $self->{name}, 'dist_vers', $self->{table});
+  my $sth  = $dbh->prepare($sql) or do {
     $self->db_error();
     return;
   };
@@ -42,7 +40,7 @@ sub fetch_ids {
   };
   my ($ids, $versions);
   while (my ($id, $key, $vers) = $sth->fetchrow_array()) {
-    $ids->{$key} = $id;
+    $ids->{$key}      = $id;
     $versions->{$key} = $vers;
   }
   $sth->finish;
@@ -60,9 +58,8 @@ use CPAN::SQLite::DBI qw($dbh);
 
 sub fetch_ids {
   my $self = shift;
-  my $sql = sprintf(qq{SELECT %s,%s from %s},
-                    $self->{id}, $self->{name}, $self->{table});
-  my $sth = $dbh->prepare($sql) or do {
+  my $sql  = sprintf(qq{SELECT %s,%s from %s}, $self->{id}, $self->{name}, $self->{table});
+  my $sth  = $dbh->prepare($sql) or do {
     $self->db_error();
     return;
   };
@@ -83,7 +80,7 @@ sub schema {
   my ($self, $data) = @_;
   my $schema = '';
   foreach my $type (qw(primary other)) {
-    foreach my $column (keys %{$data->{$type}}) {
+    foreach my $column (keys %{ $data->{$type} }) {
       $schema .= $column . ' ' . $data->{$type}->{$column} . ", ";
     }
   }
@@ -93,14 +90,13 @@ sub schema {
 
 sub create_index {
   my ($self, $data) = @_;
-  my $key = $data->{key};
+  my $key   = $data->{key};
   my $table = $self->{table};
   return 1 unless (defined $key and ref($key) eq 'ARRAY');
-  foreach my $index(@$key) {
+  foreach my $index (@$key) {
     my $id_name = 'ix_' . $table . '_' . $index;
     $id_name =~ s/\(\s*\d+\s*\)//;
-    my $sql = 'CREATE INDEX ' . $id_name . ' ON ' .
-      $table . '( ' . $index . ' )';
+    my $sql = 'CREATE INDEX ' . $id_name . ' ON ' . $table . '( ' . $index . ' )';
     my $sth = $dbh->prepare($sql);
     $sth->execute() or do {
       $self->db_error($sth);
@@ -113,11 +109,10 @@ sub create_index {
 }
 
 sub drop_table {
-  my $self = shift;
+  my $self  = shift;
   my $table = $self->{table};
-  my $sql = qq{SELECT name FROM sqlite_master } .
-    qq{ WHERE type='table' AND name=?};
-  my $sth = $dbh->prepare($sql);
+  my $sql   = qq{SELECT name FROM sqlite_master } . qq{ WHERE type='table' AND name=?};
+  my $sth   = $dbh->prepare($sql);
   $sth->execute($table);
   if (defined $sth->fetchrow_array) {
     $dbh->do(qq{drop table $table}) or do {
@@ -148,11 +143,11 @@ sub create_tables {
   my ($self, %args) = @_;
   return unless $args{setup};
   my $objs = $self->{objs};
-  foreach my $table(keys %$objs) {
+  foreach my $table (keys %$objs) {
     next unless my $schema = $self->schema($tables->{$table});
     my $obj = $objs->{$table};
-    $obj->drop_table or return;
-    $obj->create_table($schema) or return;
+    $obj->drop_table                      or return;
+    $obj->create_table($schema)           or return;
     $obj->create_index($tables->{$table}) or return;
   }
   return 1;
@@ -162,8 +157,7 @@ sub sth_insert {
   my ($self, $fields) = @_;
   my $flds = join ',', @{$fields};
   my $vals = join ',', map { '?' } @{$fields};
-  my $sql = sprintf(qq{INSERT INTO %s (%s) VALUES (%s)},
-                    $self->{table}, $flds, $vals);
+  my $sql = sprintf(qq{INSERT INTO %s (%s) VALUES (%s)}, $self->{table}, $flds, $vals);
 
   my $sth = $dbh->prepare($sql) or do {
     $self->db_error();
@@ -175,8 +169,7 @@ sub sth_insert {
 sub sth_update {
   my ($self, $fields, $id, $rep_id) = @_;
   my $set = join ',', map { "$_=?" } @{$fields};
-  my $sql = sprintf(qq{UPDATE %s SET %s WHERE %s = %s},
-                    $self->{table}, $set, $self->{id}, $id);
+  my $sql = sprintf(qq{UPDATE %s SET %s WHERE %s = %s}, $self->{table}, $set, $self->{id}, $id);
   $sql .= qq { AND rep_id = $rep_id } if ($rep_id);
   my $sth = $dbh->prepare($sql) or do {
     $self->db_error();
@@ -187,8 +180,7 @@ sub sth_update {
 
 sub sth_delete {
   my ($self, $table_id, $rep_id) = @_;
-  my $sql = sprintf(qq{DELETE FROM %s where %s = ?},
-                    $self->{table}, $table_id);
+  my $sql = sprintf(qq{DELETE FROM %s where %s = ?}, $self->{table}, $table_id);
   $sql .= qq { AND rep_id = $rep_id } if ($rep_id);
   my $sth = $dbh->prepare($sql) or do {
     $self->db_error();
@@ -205,7 +197,7 @@ CPAN::SQLite::DBI::Index - DBI information for indexing the CPAN::SQLite databas
 
 =head1 VERSION
 
-version 0.214
+version 0.215
 
 =head1 DESCRIPTION
 
