@@ -1,17 +1,18 @@
-# $Id: State.pm 70 2019-01-04 19:39:59Z stro $
+# $Id: State.pm 73 2019-01-23 22:29:38Z stro $
 
 package CPAN::SQLite::State;
 use strict;
 use warnings;
 no warnings qw(redefine);
 
-our $VERSION = '0.214';
+our $VERSION = '0.215';
 
 use English qw/-no_match_vars/;
 
 use CPAN::SQLite::DBI qw($dbh);
 use CPAN::SQLite::DBI::Index;
 use CPAN::SQLite::Util qw(has_hash_data print_debug);
+use Scalar::Util 'weaken';
 
 my %tbl2obj;
 $tbl2obj{$_} = __PACKAGE__ . '::' . $_ for (qw(dists mods auths info));
@@ -26,7 +27,7 @@ sub new {
     die "No state information available under setup";
   }
 
-  my $index = $args{index};
+  my $index  = $args{index};
   my @tables = qw(dists mods auths info);
   foreach my $table (@tables) {
     my $obj = $index->{$table};
@@ -35,11 +36,12 @@ sub new {
   }
   my $cdbi = CPAN::SQLite::DBI::Index->new(%args);
 
-  my $self = {index => $index,
-              obj => {},
-              cdbi => $cdbi,
-              reindex => $args{reindex},
-             };
+  my $self = {
+    index   => $index,
+    obj     => {},
+    cdbi    => $cdbi,
+    reindex => $args{reindex},
+  };
   return bless $self, $class;
 }
 
@@ -52,25 +54,26 @@ sub state {
   unless ($self->state_info()) {
     print_debug("Getting state information failed");
     return;
-  };
+  }
   return 1;
 }
 
 sub create_objs {
-  my $self = shift;
+  my $self   = shift;
   my @tables = qw(dists auths mods info);
 
   foreach my $table (@tables) {
     my $obj;
-    my $pack = $tbl2obj{$table};
+    my $pack  = $tbl2obj{$table};
     my $index = $self->{index}->{$table};
     if ($index and ref($index) eq "CPAN::SQLite::Index::$table") {
       my $info = $index->{info};
       if ($table ne 'info') {
         return unless has_hash_data($info);
       }
-      $obj = $pack->new(info => $info,
-                        cdbi => $self->{cdbi}->{objs}->{$table});
+      $obj = $pack->new(
+        info => $info,
+        cdbi => $self->{cdbi}->{objs}->{$table});
     } else {
       $obj = $pack->new();
     }
@@ -82,15 +85,16 @@ sub create_objs {
     foreach (@tables) {
       next if ref($obj) eq $tbl2obj{$_};
       $obj->{obj}->{$_} = $self->{obj}->{$_};
+      weaken $obj->{obj}->{$_};
     }
   }
   return 1;
 }
 
 sub state_info {
-  my $self = shift;
+  my $self    = shift;
   my @methods = qw(ids state);
-  my @tables = qw(dists auths mods);
+  my @tables  = qw(dists auths mods);
 
   for my $method (@methods) {
     for my $table (@tables) {
@@ -99,8 +103,7 @@ sub state_info {
         if (my $error = $obj->{error_msg}) {
           print_debug("Fatal error from ", ref($obj), ": ", $error, $/);
           return;
-        }
-        else {
+        } else {
           my $info = $obj->{info_msg};
           print_debug("Info from ", ref($obj), ": ", $info, $/);
         }
@@ -127,16 +130,16 @@ sub new {
   die "No dbi object available"
     unless ($cdbi and ref($cdbi) eq 'CPAN::SQLite::DBI::Index::auths');
   my $self = {
-              info => $info,
-              insert => {},
-              update => {},
-              delete => {},
-              ids => {},
-              obj => {},
-              cdbi => $cdbi,
-              error_msg => '',
-              info_msg => '',
-             };
+    info      => $info,
+    insert    => {},
+    update    => {},
+    delete    => {},
+    ids       => {},
+    obj       => {},
+    cdbi      => $cdbi,
+    error_msg => '',
+    info_msg  => '',
+  };
   return bless $self, $class;
 }
 
@@ -151,20 +154,20 @@ sub ids {
 }
 
 sub state {
-  my $self = shift;
+  my $self     = shift;
   my $auth_ids = $self->{ids};
   return unless my $dist_obj = $self->{obj}->{dists};
   my $dist_update = $dist_obj->{update};
   my $dist_insert = $dist_obj->{insert};
-  my $dists = $dist_obj->{info};
+  my $dists       = $dist_obj->{info};
   my ($update, $insert);
   if (has_hash_data($dist_insert)) {
+
     foreach my $distname (keys %{$dist_insert}) {
       my $cpanid = $dists->{$distname}->{cpanid};
       if (my $auth_id = $auth_ids->{$cpanid}) {
         $update->{$cpanid} = $auth_id;
-      }
-      else {
+      } else {
         $insert->{$cpanid}++;
       }
     }
@@ -174,8 +177,7 @@ sub state {
       my $cpanid = $dists->{$distname}->{cpanid};
       if (my $auth_id = $auth_ids->{$cpanid}) {
         $update->{$cpanid} = $auth_id;
-      }
-      else {
+      } else {
         $insert->{$cpanid}++;
       }
     }
@@ -197,17 +199,17 @@ sub new {
   die "No dbi object available"
     unless ($cdbi and ref($cdbi) eq 'CPAN::SQLite::DBI::Index::dists');
   my $self = {
-              info => $info,
-              insert => {},
-              update => {},
-              delete => {},
-              ids => {},
-              versions => {},
-              obj => {},
-              cdbi => $cdbi,
-              error_msg => '',
-              info_msg => '',
-              reindex => undef,
+    info      => $info,
+    insert    => {},
+    update    => {},
+    delete    => {},
+    ids       => {},
+    versions  => {},
+    obj       => {},
+    cdbi      => $cdbi,
+    error_msg => '',
+    info_msg  => '',
+    reindex   => undef,
   };
   return bless $self, $class;
 }
@@ -223,16 +225,16 @@ sub ids {
 }
 
 sub state {
-  my $self = shift;
+  my $self          = shift;
   my $dist_versions = $self->{versions};
-  my $dists = $self->{info};
-  my $dist_ids = $self->{ids};
+  my $dists         = $self->{info};
+  my $dist_ids      = $self->{ids};
   my ($insert, $update, $delete);
 
   my $reindex = $self->{reindex};
   if (defined $reindex) {
     my @dists = ref($reindex) eq 'ARRAY' ? @$reindex : ($reindex);
-    foreach my $distname(@dists) {
+    foreach my $distname (@dists) {
       my $id = $dist_ids->{$distname};
       if (not defined $id) {
         print_debug(qq{"$distname" does not have an id: reindexing ignored\n});
@@ -253,7 +255,7 @@ sub state {
   }
   $self->{update} = $update;
   $self->{insert} = $insert;
-  foreach my $distname(keys %$dist_versions) {
+  foreach my $distname (keys %$dist_versions) {
     next if $dists->{$distname};
     $delete->{$distname} = $dist_ids->{$distname};
     print_debug("Will delete $distname\n");
@@ -274,16 +276,16 @@ sub new {
   die "No dbi object available"
     unless ($cdbi and ref($cdbi) eq 'CPAN::SQLite::DBI::Index::mods');
   my $self = {
-              info => $info,
-              insert => {},
-              update => {},
-              delete => {},
-              ids => {},
-              obj => {},
-              cdbi => $cdbi,
-              error_msg => '',
-              info_msg => '',
-             };
+    info      => $info,
+    insert    => {},
+    update    => {},
+    delete    => {},
+    ids       => {},
+    obj       => {},
+    cdbi      => $cdbi,
+    error_msg => '',
+    info_msg  => '',
+  };
   return bless $self, $class;
 }
 
@@ -298,29 +300,29 @@ sub ids {
 }
 
 sub state {
-  my $self = shift;
+  my $self    = shift;
   my $mod_ids = $self->{ids};
   return unless my $dist_obj = $self->{obj}->{dists};
-  my $dists = $dist_obj->{info};
+  my $dists       = $dist_obj->{info};
   my $dist_update = $dist_obj->{update};
   my $dist_insert = $dist_obj->{insert};
   my ($update, $insert, $delete);
   my $cdbi = $self->{cdbi};
+
   if (has_hash_data($dist_insert)) {
     foreach my $distname (keys %{$dist_insert}) {
-      foreach my $module(keys %{$dists->{$distname}->{modules}}) {
+      foreach my $module (keys %{ $dists->{$distname}->{modules} }) {
         $insert->{$module}++;
       }
     }
   }
   if (has_hash_data($dist_update)) {
     foreach my $distname (keys %{$dist_update}) {
-      foreach my $module(keys %{$dists->{$distname}->{modules}}) {
+      foreach my $module (keys %{ $dists->{$distname}->{modules} }) {
         my $mod_id = $mod_ids->{$module};
         if ($mod_id) {
           $update->{$module} = $mod_id;
-        }
-        else {
+        } else {
           $insert->{$module}++;
         }
       }
@@ -337,13 +339,13 @@ sub state {
     my $dist_ids = $dist_obj->{ids};
     foreach my $distname (keys %{$dist_update}) {
       my %mods = ();
-      %mods = map {$_ => 1} keys %{$dists->{$distname}->{modules}};
+      %mods = map { $_ => 1 } keys %{ $dists->{$distname}->{modules} };
       $sth->execute($dist_ids->{$distname}) or do {
         $cdbi->db_error($sth);
         $self->{error_msg} = $cdbi->{error_msg};
         return;
       };
-      while (my($mod_id, $mod_name) = $sth->fetchrow_array) {
+      while (my ($mod_id, $mod_name) = $sth->fetchrow_array) {
         next if $mods{$mod_name};
         $delete->{$mod_name} = $mod_id;
       }
@@ -368,16 +370,16 @@ sub new {
   die "No dbi object available"
     unless ($cdbi and ref($cdbi) eq 'CPAN::SQLite::DBI::Index::info');
   my $self = {
-              info => '',
-              insert => {},
-              update => {},
-              delete => {},
-              ids => {},
-              obj => {},
-              cdbi => $cdbi,
-              error_msg => '',
-              info_msg => '',
-             };
+    info      => '',
+    insert    => {},
+    update    => {},
+    delete    => {},
+    ids       => {},
+    obj       => {},
+    cdbi      => $cdbi,
+    error_msg => '',
+    info_msg  => '',
+  };
   return bless $self, $class;
 }
 
@@ -399,7 +401,7 @@ CPAN::SQLite::State - get state information on the database
 
 =head1 VERSION
 
-version 0.214
+version 0.215
 
 =head1 DESCRIPTION
 
